@@ -1,5 +1,5 @@
 #!/usr/local/bin/perl -w
-# $Revision: #6 $$Date: 2002/07/16 $$Author: wsnyder $
+# $Revision: #7 $$Date: 2003/07/16 $$Author: wsnyder $
 # DESCRIPTION: Perl ExtUtils: Type 'make test' to test this package
 
 my $dir = "test_dir";
@@ -12,8 +12,7 @@ if ($Use_SCL) {
 print "Building example...\n";
 if ($Config{archname} !~ /linux/
     || !$ENV{SYSTEMC}) {
-    print "Skipping: Not linux with systemc installed\n";
-    skip(1,1);
+    skip("skip Not linux or missing SystemC",1);
 } else {
     run_system ("cd $dir && make -j 3 -f ../example/Makefile_obj");
     ok(1);
@@ -23,9 +22,9 @@ print "Running example...\n";
 if (! -x "$dir/ex_main"
     || $Use_SCL  # For now...
     ) {
-    skip(1,1);
-    skip(1,1);
-    skip(1,1);
+    skip("skip Not linux or missing SystemC",1);
+    skip("skip Not linux or missing SystemC",1);
+    skip("skip Not linux or missing SystemC",1);
 } else {
     run_system ("cd $dir && ./ex_main");
     ok(1);
